@@ -4,9 +4,14 @@ import httpx
 
 from ...client import Client
 from ...models.file_conversion import FileConversion
+from ...models.file2_d_vector_conversion import File2DVectorConversion
+from ...models.file3_d_conversion import File3DConversion
+from ...models.file_center_of_mass import FileCenterOfMass
+from ...models.file_center_of_mass_with_uniform_density import FileCenterOfMassWithUniformDensity
 from ...models.file_mass import FileMass
 from ...models.file_volume import FileVolume
 from ...models.file_density import FileDensity
+from ...models.file_surface_area import FileSurfaceArea
 from ...models.error import Error
 from ...types import Response
 
@@ -28,7 +33,7 @@ def _get_kwargs(
 	}
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	if response.status_code == 200:
 		data = response.json()
 		try:
@@ -38,6 +43,34 @@ def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, FileConv
 			return option
 		except:
 			pass
+		try:
+			if not isinstance(data, dict):
+				raise TypeError()
+			option = File2DVectorConversion.from_dict(data)
+			return option
+		except:
+			pass
+		try:
+			if not isinstance(data, dict):
+				raise TypeError()
+			option = File3DConversion.from_dict(data)
+			return option
+		except:
+			pass
+		try:
+			if not isinstance(data, dict):
+				raise TypeError()
+			option = FileCenterOfMass.from_dict(data)
+			return option
+		except:
+			pass
+		try:
+			if not isinstance(data, dict):
+				raise TypeError()
+			option = FileCenterOfMassWithUniformDensity.from_dict(data)
+			return option
+		except:
+			pass
 		try:
 			if not isinstance(data, dict):
 				raise TypeError()
@@ -57,6 +90,13 @@ def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, FileConv
 				raise TypeError()
 			option = FileDensity.from_dict(data)
 			return option
+		except:
+			pass
+		try:
+			if not isinstance(data, dict):
+				raise TypeError()
+			option = FileSurfaceArea.from_dict(data)
+			return option
 		except:
 			raise
 	if response.status_code == 400:
@@ -68,7 +108,7 @@ def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, FileConv
 	return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+def _build_response(*, response: httpx.Response) -> Response[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	return Response(
 		status_code=response.status_code,
 		content=response.content,
@@ -81,7 +121,7 @@ def sync_detailed(
 	id: str,
 	*,
 	client: Client,
-) -> Response[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+) -> Response[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	kwargs = _get_kwargs(
 		id=id,
 		client=client,
@@ -99,7 +139,7 @@ def sync(
 	id: str,
 	*,
 	client: Client,
-) -> Optional[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+) -> Optional[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	""" Get the status and output of an async file conversion. If completed, the contents of the converted file (`output`) will be returned as a base64 encoded string.
 This endpoint requires authentication by any KittyCAD user. It returns details of the requested file conversion for the user. """
 
@@ -113,7 +153,7 @@ async def asyncio_detailed(
 	id: str,
 	*,
 	client: Client,
-) -> Response[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+) -> Response[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	kwargs = _get_kwargs(
 		id=id,
 		client=client,
@@ -129,7 +169,7 @@ async def asyncio(
 	id: str,
 	*,
 	client: Client,
-) -> Optional[Union[Any, FileConversion, FileMass, FileVolume, FileDensity, Error]]:
+) -> Optional[Union[Any, FileConversion, File2DVectorConversion, File3DConversion, FileCenterOfMass, FileCenterOfMassWithUniformDensity, FileMass, FileVolume, FileDensity, FileSurfaceArea, Error]]:
 	""" Get the status and output of an async file conversion. If completed, the contents of the converted file (`output`) will be returned as a base64 encoded string.
 This endpoint requires authentication by any KittyCAD user. It returns details of the requested file conversion for the user. """
 
