@@ -5,8 +5,10 @@ class FileImportFormat(str, Enum):
     DAE = 'dae'
     DXF = 'dxf'
     FBX = 'fbx'
+    OBJ_ZIP = 'obj_zip'
     OBJ = 'obj'
     OBJ_NOMTL = 'obj_nomtl'
+    PLY = 'ply'
     STEP = 'step'
     STL = 'stl'
     SVG = 'svg'
